﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p09_en_02
{
    public partial class Form1 : Form
    {
        //Delegates declaration for communication between threads.
        private delegate void DelEndPutData(int WID, int Result, int Param);
        private delegate void DelEndGetData(int WID, int Result, int Param, object DATA);

        //Necessary objects and variables definition.
        AtouchApp App = new AtouchApp();
        int Err;
        Object Data = new Object();

        public Form1()
        {
            InitializeComponent();
            //After-communication event handlers initialization. When App.xxx += is writed and then 
            //the Tab key is double pressed, the event code block is created automatically.
            App.EndNetGetData += new _IAtouchAppEvents_EndNetGetDataEventHandler(App_EndNetGetData);
            App.EndNetPutData += new _IAtouchAppEvents_EndNetPutDataEventHandler(App_EndNetPutData);
        }

        void App_EndNetPutData(int WID, int Result, int Param)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelEndPutData(App_EndNetPutData), new Object[] { WID, Result, Param });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //Call on a form control after a write request execution.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Communication ended OK.
                ComText.Text = "OK";
            }
            else
            {   //Communication ended with error. 
                ComText.Text = Result.ToString();
            }
        }

        void App_EndNetGetData(int WID, int Result, int Param, object DATA)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelEndGetData(App_EndNetGetData), new Object[] { WID, Result, Param, DATA });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //Call on a form control after a read request execution.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Communication ended OK.
                ComText.Text = "OK";
                switch (Param)
                {
                    case 1:
                        ReadInt.Text = DATA.ToString();
                        break;
                    case 2:
                        ReadLon.Text = DATA.ToString();
                        break;
                    case 3:
                        ReadFlo.Text = DATA.ToString();
                        break;
                }
            }
            else
            {   //Communication ended with error.
                ComText.Text = Result.ToString();
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Initialization method for DB-net network communication.
            App.VariantOnly = false;
            Err = App.InitFromFile("hw.ini", "db.ini");
            ErrText.Text = Err.ToString();
        }

        //DB-Net network communication termination.
        private void EndProg_Click(object sender, EventArgs e)
        {
            App.Done();
            this.Close();
        }

        //Variables reading from control system: the WID and identification parameter are sent.
        private void ButReadInt_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(1001, 1);
            ErrText.Text = Err.ToString();
        }

        private void ButReadLon_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(1003, 2);
            ErrText.Text = Err.ToString();
        }

        private void ButReadFlo_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(1005, 3);
            ErrText.Text = Err.ToString();
        }

        //Variables writing to control system: the WID and identification parameter and new value are sent.
        private void ButWriteInt_Click(object sender, EventArgs e)
        {
            Data = Convert.ToInt16(WriteInt.Text);
            //Int type in control system has length of 2B, therefore the value must me converted to C# Int16 type.
            Err = App.NetPutData(1001, 1, Data);
        }

        private void ButWriteLon_Click(object sender, EventArgs e)
        {
            Data = Convert.ToInt32(WriteLon.Text);
            Err = App.NetPutData(1003, 2, Data);
        }

        private void ButWriteFlo_Click(object sender, EventArgs e)
        {
            Data = Convert.ToSingle(WriteFlo.Text);
            Err = App.NetPutData(1005, 3, Data);
        }
    }
}