﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p11_en_02
{
    public partial class Form1 : Form
    {
        //Delegates declaration for communication between threads.
        private delegate void DelEndPutData(short Station, int Result, int Param);
        private delegate void DelEndGetData(short Station, int Result, int Param, DateTime Date);

        //Necessary objects and variables definition.
        AtouchApp App = new AtouchApp();
        int Err;

        public Form1()
        {
            InitializeComponent();
            //After-communication event handlers initialization. When App.xxx += is writed and then 
            //the Tab key is double pressed, the event code block is created automatically.
            App.EndNetGetTime += new _IAtouchAppEvents_EndNetGetTimeEventHandler(App_EndNetGetTime);
            App.EndNetPutTime += new _IAtouchAppEvents_EndNetPutTimeEventHandler(App_EndNetPutTime);
        }

        void App_EndNetPutTime(short Station, int Result, int Param)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelEndPutData(App_EndNetPutTime), new Object[] { Station, Result, Param });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //Call on a form control after a write request execution.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Communication ended OK.
                ComText.Text = "OK";
            }
            else
            {   //Communication ended with error. 
                ComText.Text = Result.ToString();
            }
        }

        void App_EndNetGetTime(short Station, int Result, int Param, DateTime DateTime)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelEndGetData(App_EndNetGetTime), new Object[] { Station, Result, Param, DateTime });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //Call on a form control after a read request execution.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Communication ended OK.
                ComText.Text = "OK";
                DTDT.Text = DateTime.ToString();
            }
            else
            {   //Communication ended with error.
                ComText.Text = Result.ToString();
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Initialization method for DB-net network communication.
            Err = App.InitFromFile("hw.ini", "db.ini");
            App.VariantOnly = false;
            ErrText.Text = Err.ToString();
        }

        //DB-Net network communication termination.
        private void EndProg_Click(object sender, EventArgs e)
        {
            App.Done();
            this.Close();
        }

        //Time read from control system.
        private void ReadTime_Click(object sender, EventArgs e)
        {
            Err = App.NetGetTime(1, 1);
            ErrText.Text = Err.ToString();
        }

        private void DefaultDT_Click(object sender, EventArgs e)
        {
            TextWrTiDate.Text = "1.1.1980 0:00:01";
        }

        //Time write to control system.
        private void WriteTimeDate_Click(object sender, EventArgs e)
        {
            DateTime DTMy;
            string DTString = TextWrTiDate.Text;
            if (TextWrTiDate.Text != "")
            {
                DTMy = Convert.ToDateTime(DTString);
                Err = App.NetPutTime(1, 1, DTMy);
                ErrText.Text = Err.ToString();
            }
        }

        //Time synchronization with PC.
        private void SyncPC_Click(object sender, EventArgs e)
        {
            DateTime DTMy = new DateTime(1980, 1, 1);
            Err = App.NetPutTime(1, 1, DTMy);
            ErrText.Text = Err.ToString();
        }
    }
}