﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p13_en_02
{
    public partial class Form1 : Form
    {
        //Delegates declaration for communication between threads.
        private delegate void DelSample(int AID, object DATA);
        private delegate void DelCompleted(int AID, int Samples);

        //Necessary objects and variables definition.
        AtouchApp App = new AtouchApp();
        AtouchArch AArch = new AtouchArch();
        int Ind = 0;
        int Err;
        Boolean boSample;

        public Form1()
        {
            InitializeComponent();
            //After-communication event handlers initialization. When App.xxx += is writed and then 
            //the Tab key is double pressed, the event code block is created automatically.
            AArch.Sample += new _IAtouchArchEvents_SampleEventHandler(AArch_Sample);
            AArch.Completed += new _IAtouchArchEvents_CompletedEventHandler(AArch_Completed);
        }

        void AArch_Completed(int AID, int Samples)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelCompleted(AArch_Completed), new Object[] { AID, Samples });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //End of operation log reading.
            AArch.Control(1, false);
            if (!boSample)
                richTextBox1.AppendText("There is not any new report.\n");
        }

        void AArch_Sample(int AID, object DATA)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelSample(AArch_Sample), new Object[] { AID, DATA });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //Some new report was read.
            String PDtext = String.Format("{0}: ", Ind++);
            if (DATA is object[])
            {
                object[] MData = (object[])DATA;
                PDtext += String.Format("{0}\t{1}", MData[0], MData[9]);
            }
            PDtext += "\n";
            AArch.Accept(1, true);
            richTextBox1.AppendText(PDtext);
            boSample = true;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Initialization method for DB-net network communication.
            Err = App.InitFromFile("hw.ini", "db.ini");
            if (Err == (Int16)AtouchX_Error_Code.arrOK)
            {
                Err = AArch.InitFromFile("PD_Arch.ini");
            }
            ErrText.Text = Err.ToString();
        }

        //DB-Net network communication termination.
        private void EndProg_Click(object sender, EventArgs e)
        {
            AArch.Done();
            App.Done();
            this.Close();
        }

        //Read operation log from control system.
        private void ReadPD_Click(object sender, EventArgs e)
        {
            boSample = false;
            Err = AArch.Control(1, true);
            ErrText.Text = Err.ToString();
        }
    }
}